@@ -13,7 +13,7 @@ strBruce="   (Applied Cryptography)   ,   Blowfish,       Counterpane Internet S
 
 strSpecialChars="   `   ~   !   @   #   $   %   ^   &   *   (   )   _   +   -   =   |   }   {   [   ]   <   >   ?   /   \   :   ;   |   "
 
-strCombination="     ,      Password Safe."
+strMasterPassword="   -  ,      Password Safe."
 
 strPopText1=""
 
