@@ -258,6 +258,14 @@ void CItem::GetField(const CItemField &field, std::vector<unsigned char> &v) con
   v.resize(length);
 }
 
+void CItem::GetField(const CItemField &field, VectorX<unsigned char> &v) const
+{
+  size_t length = roundUp(field.GetLength(), BlowFish::BLOCKSIZE);
+  v.resize(length);
+  field.Get(& v[0], length, MakeBlowFish());
+  v.resize(length);
+}
+
 void CItem::GetField(const int ft, std::vector<unsigned char> &v) const
 {
   auto fiter = m_fields.find(ft);
@@ -268,6 +276,16 @@ void CItem::GetField(const int ft, std::vector<unsigned char> &v) const
   GetField(fiter->second, v);
 }
 
+void CItem::GetField(const int ft, VectorX<unsigned char> &v) const
+{
+  auto fiter = m_fields.find(ft);
+  if (fiter == m_fields.end()) {
+    v.clear();
+    return;
+  }
+  GetField(fiter->second, v);
+}
+
 uint8_t CItem::GetFieldAsByte(const CItemField& field, uint8_t default_value) const
 {
   std::vector<uint8_t> v;
