@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -12,6 +12,11 @@
 #ifndef __PWSFILEV1V2_H
 #define __PWSFILEV1V2_H
 
+#ifndef _MSC_VER
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Woverloaded-virtual"
+#endif
+
 #include "PWSfile.h"
 #include "crypto/BlowFish.h"
 
@@ -43,4 +48,8 @@ private:
   int ReadV2Header();
 };
 
+#ifndef _MSC_VER
+#pragma GCC diagnostic pop
+#endif
+
 #endif /*  __PWSFILEV1V2_H */
