@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -103,6 +103,11 @@ bool XMLFileHandlers::ProcessStartElement(const int icurrent_element)
       m_cur_entry->title = _T("");
       m_cur_entry->username = _T("");
       m_cur_entry->password = _T("");
+      m_cur_entry->twofactorkey = _T("");
+      m_cur_entry->totpconfig = _T("");
+      m_cur_entry->totpstarttime = _T("");
+      m_cur_entry->totptimestep = _T("");
+      m_cur_entry->totplength = _T("");
       m_cur_entry->url = _T("");
       m_cur_entry->autotype = _T("");
       m_cur_entry->ctime = _T("");
@@ -281,6 +286,9 @@ void XMLFileHandlers::ProcessEndElement(const int icurrent_element)
     case XLE_PREF_COPYPASSWORDWHENBROWSETOURL:
       bpref = PWSprefs::CopyPasswordWhenBrowseToURL;
       break;
+    case XLE_PREF_EXCLUDEFROMSCREENCAPTURE:
+      bpref = PWSprefs::ExcludeFromScreenCapture;
+      break;
     // Integer DB preferences
     case XLE_PREF_PWDEFAULTLENGTH:
       if (m_bPolicyBeingProcessed)
@@ -414,6 +422,21 @@ void XMLFileHandlers::ProcessEndElement(const int icurrent_element)
         }
       }
       break;
+    case XLE_TWOFACTORKEY:
+      m_cur_entry->twofactorkey = m_sxElemContent;
+      break;
+    case XLE_TOTPCONFIG:
+      m_cur_entry->totpconfig = m_sxElemContent;
+      break;
+    case XLE_TOTPSTARTTIME:
+      m_cur_entry->totpstarttime = m_sxElemContent;
+      break;
+    case XLE_TOTPTIMESTEP:
+      m_cur_entry->totptimestep = m_sxElemContent;
+      break;
+    case XLE_TOTPLENGTH:
+      m_cur_entry->totplength = m_sxElemContent;
+      break;
     case XLE_CTIMEX:
       m_cur_entry->ctime = m_sxElemContent;
       break;
@@ -758,6 +781,23 @@ void XMLFileHandlers::AddXMLEntries()
     if (!cur_entry->password.empty())
       ci_temp.SetPassword(cur_entry->password);
 
+    if (!cur_entry->twofactorkey.empty()) {
+
+      ci_temp.SetTwoFactorKey(cur_entry->twofactorkey);
+
+      if (!cur_entry->totpconfig.empty())
+        ci_temp.SetTotpConfig(cur_entry->totpconfig);
+
+      if (!cur_entry->totpstarttime.empty())
+        ci_temp.SetTotpStartTime(cur_entry->totpstarttime);
+
+      if (!cur_entry->totptimestep.empty())
+        ci_temp.SetTotpTimeStep(cur_entry->totptimestep);
+
+      if (!cur_entry->totplength.empty())
+        ci_temp.SetTotpLength(cur_entry->totplength);
+    }
+
     EmptyIfOnlyWhiteSpace(cur_entry->url);
     if (!cur_entry->url.empty())
       ci_temp.SetURL(cur_entry->url);
