@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -13,7 +13,7 @@
 #define __TWOFISH_H
 
 #include "Fish.h"
-#include "os/typedefs.h"
+#include "../../os/typedefs.h"
 
 #ifndef TWOFISH_SMALL
 struct twofish_key {
