@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -15,6 +15,8 @@
 // HMAC algorithm as per RFC2104
 
 #include "../Util.h" // for ASSERT
+#include "sha1.h"
+#include "sha256.h"
 
 class HMAC_BASE
 {
@@ -38,12 +40,14 @@ public:
 template<class H, unsigned int HASHLEN, unsigned int BLOCKSIZE>
 class HMAC : public HMAC_BASE
 {
+public:
+  static const size_t HASH_LENGTH = HASHLEN;
 public:
   HMAC(const unsigned char *key, unsigned long keylen)
     : HMAC_BASE(), Hash(nullptr)
   {
     ASSERT(key != nullptr);
-    
+
     memset(K, 0, sizeof(K));
     Init(key, keylen);
   }
@@ -131,6 +135,9 @@ private:
   unsigned char K[BLOCKSIZE];
 };
 
+using HMAC_SHA1 = HMAC<SHA1, SHA1::HASHLEN, SHA1::BLOCKSIZE>;
+using HMAC_SHA256 = HMAC<SHA256, SHA256::HASHLEN, SHA256::BLOCKSIZE>;
+
 #endif /* __HMAC_H */
 //-----------------------------------------------------------------------------
 // Local variables:
