@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -7,7 +7,7 @@
 */
 #ifndef __SHA1_H
 #define __SHA1_H
-#include "os/typedefs.h"
+#include "../../os/typedefs.h"
 
 class SHA1
 {
@@ -16,12 +16,12 @@ public:
   static const unsigned int BLOCKSIZE = 64;
   SHA1();
   ~SHA1();
-  void Update(const unsigned char* data, unsigned int len);
+  void Update(const unsigned char* data, uint64 len);
   void Final(unsigned char digest[HASHLEN]);
 
 private:
   uint32 state[5];
-  uint32 count[2];
+  uint64 count;  // Use a single 64-bit value instead of two 32-bit values
   unsigned char buffer[BLOCKSIZE];
 };
 #endif /* __SHA1_H */
