@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -43,4 +43,18 @@ namespace pws_os {
   bool DisableDumpAttach();
 }
 
+#if defined(_DEBUG) || defined(DEBUG)
+
+#define PWSTRACE(lpszFormat,...) pws_os::Trace(lpszFormat,__VA_ARGS__)
+
+#else
+
+#ifdef _WIN32
+#define PWSTRACE(lpszFormat,...) __noop
+#else
+#define PWSTRACE(lpszFormat,...) do {} while(0)
+#endif
+
+#endif
+
 #endif /* _OSDEBUG_H */
