@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -30,11 +30,3 @@ int localtime64_r(const __time64_t *timep, struct tm *result)
   return localtime_r(tp, result) != nullptr;
 }
 
-int pws_os::asctime(TCHAR *s, size_t, tm const *t)
-{
-  char cbuf[26]; // length specified in man (3) asctime
-  asctime_r(t, cbuf);
-  std::wstring wstr = pws_os::towc(cbuf);
-  std::copy(wstr.begin(), wstr.end(), s);
-  return 0;
-}
