@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -21,13 +21,6 @@ typedef __TIME64_T_TYPE __time64_t;
 
 extern int localtime64_r(const __time64_t *timep, struct tm *result);
 
-namespace pws_os {
-  /**
-   * Workaround the lack of a wchar_t version of asctime()
-   */
-  extern int asctime(TCHAR *buf, size_t N, const struct tm *tm);
-}
-
 #endif /* __PWS_TIME_H */
 //-----------------------------------------------------------------------------
 // Local variables:
