@@ -111,6 +111,7 @@ void PasswordSafeFrame::OnAddClick(wxCommandEvent& WXUNUSED(evt))
   int rc = ShowModalAndGetResult<AddEditPropSheetDlg>(this, m_core, AddEditPropSheetDlg::SheetType::ADD, nullptr, selectedGroup);
   if (rc == wxID_OK) {
     UpdateStatusBar();
+    Show();
   }
 }
 
@@ -958,7 +959,7 @@ void PasswordSafeFrame::DoBrowse(CItemData &item, bool bAutotype)
 
 bool PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX & WXUNUSED(sxAutotype),
                              const std::vector<size_t> & WXUNUSED(vactionverboffsets),
-                             bool WXUNUSED(bDoAutotype))
+                             bool WXUNUSED(bDoAutotype)) const
 {
   /*
    * This is a straight port of DBoxMain::LaunchBrowser.  See the comments in that function
@@ -1032,7 +1033,7 @@ bool PasswordSafeFrame::LaunchBrowser(const wxString &csURL, const StringX & WXU
 #endif
 
   if (!rc) {
-    wxMessageBox(errMsg, wxTheApp->GetAppName(), wxOK|wxICON_STOP, this);
+    wxMessageBox(errMsg, wxTheApp->GetAppName(), wxOK|wxICON_STOP, const_cast<PasswordSafeFrame*>(this));
   }
   return rc;
 }
