@@ -138,6 +138,7 @@ int PasswordSafeFrame::New()
   m_sysTray->SetTrayStatus(SystemTray::TrayStatus::UNLOCKED);
   m_RUEList.ClearEntries();
   wxGetApp().recentDatabases().AddFileToHistory(towxstring(cs_newfile));
+  CreateMenubar(); // Recreate the menu with updated list of most recently used DBs
   ResetFilters();
   GetSearchBarPane().Hide(); // There is nothing to search for in an empty database
   m_AuiManager.Update();
@@ -242,13 +243,18 @@ void PasswordSafeFrame::OnOpenClick(wxCommandEvent& WXUNUSED(evt))
   int rc = DoOpen(_("Open Password Database"));
 
   if (rc == PWScore::SUCCESS) {
-    m_core.ResumeOnDBNotification();
-    CreateMenubar(); // Recreate the menu with updated list of most recently used DBs
-    UpdateSearchBarVisibility();
-    m_AuiManager.Update();
+    FinishGoodOpen();
   }
 }
 
+void PasswordSafeFrame::FinishGoodOpen()
+{
+  m_core.ResumeOnDBNotification();
+  CreateMenubar(); // Recreate the menu with updated list of most recently used DBs
+  UpdateSearchBarVisibility();
+  m_AuiManager.Update();
+}
+
 /*!
  * wxEVT_COMMAND_MENU_SELECTED event handler for wxID_CLOSE
  */
