@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -82,7 +82,7 @@ protected:
 
 private:
 
-  void InitDialog();
+  void InitDialog() override;
   void SetValidators();
 
   //(*Handlers(pwFiltersStatusDlg)
