@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -44,12 +44,14 @@ void QueryCancelDlg::OnCancelClick(wxCommandEvent& /*event*/) {
 bool QueryCancelDlg::SyncAndQueryCancel(bool showDialog) {
   if (!(Validate() && TransferDataFromWindow()) || IsChanged()) {
     if (showDialog) {
-      auto res = wxMessageDialog(
+      wxMessageDialog dialog(
         nullptr,
-        _("Unsaved changes have been made. Are you sure you wish to cancel?"), wxEmptyString,
-        wxYES_NO | wxNO_DEFAULT | wxICON_EXCLAMATION
-      ).ShowModal();
-      if (res == wxID_YES) {
+        _("Do you want to discard the changes?"), wxEmptyString,
+        wxOK | wxCANCEL | wxCANCEL_DEFAULT | wxICON_EXCLAMATION
+      );
+      dialog.SetOKLabel(_("Discard"));
+      auto res = dialog.ShowModal();
+      if (res == wxID_OK) {
         return true;
       }
     }
