@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2020 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -17,6 +17,8 @@
 
 #include "wxUtilities.h"
 
+class CReport;
+
 /*
  * SelectionCriteria data structure backs the AdvancedSelectionPanel widget
  * 
@@ -80,7 +82,8 @@ public:
   wxString GetGroupSelectionDescription() const;
   //returns true if all fields have been selected
   bool GetFieldSelection(wxArrayString& selectedFields, wxArrayString& unselectedFields);
-
+  void ReportAdvancedOptions(CReport* rpt, const wxString& operation, const wxString& fullPath);
+  
 SelectionCriteria& operator=(const SelectionCriteria& data) {
     m_fCaseSensitive    = data.m_fCaseSensitive;
     m_bsFields          = data.m_bsFields;
