@@ -21,6 +21,8 @@
 #include "./graphics/toolbar/new/close_disabled.xpm"
 #include "./graphics/toolbar/new/lock.xpm"
 #include "./graphics/toolbar/new/lock_disabled.xpm"
+#include "./graphics/toolbar/new/unlock.xpm"
+#include "./graphics/toolbar/new/unlock_disabled.xpm"
 #include "./graphics/toolbar/new/save.xpm"
 #include "./graphics/toolbar/new/save_disabled.xpm"
 #include "./graphics/toolbar/new/copypassword.xpm"
@@ -103,6 +105,8 @@
 #include "./graphics/toolbar/classic/close_disabled.xpm"
 #include "./graphics/toolbar/classic/lock.xpm"
 #include "./graphics/toolbar/classic/lock_disabled.xpm"
+#include "./graphics/toolbar/classic/unlock.xpm"
+#include "./graphics/toolbar/classic/unlock_disabled.xpm"
 #include "./graphics/toolbar/classic/save.xpm"
 #include "./graphics/toolbar/classic/save_disabled.xpm"
 #include "./graphics/toolbar/classic/copypassword.xpm"
@@ -235,6 +239,7 @@ _PwsToolbarInfo(int aid, const wxString &atoollabel, const wxString &atooltip, c
           { wxID_OPEN,         _("Open"),            _("Open Another Database"),        PWS_TOOLBAR_BITMAPS(open)           },
           { wxID_CLOSE,        _("Close"),           _("Close Database"),               PWS_TOOLBAR_BITMAPS(close)          },
           { ID_LOCK_SAFE,      _("Lock"),            _("Lock Database"),                PWS_TOOLBAR_BITMAPS(lock)           },
+          { ID_UNLOCK_SAFE,    _("Unlock"),          _("Unlock Database"),              PWS_TOOLBAR_BITMAPS(unlock)         },
           { wxID_SAVE,         _("Save"),            _("Save Database"),                PWS_TOOLBAR_BITMAPS(save)           },
           SEPARATOR,
           { ID_COPYPASSWORD,   _("Password"),        _("Copy Password to Clipboard"),   PWS_TOOLBAR_BITMAPS(copypassword)   },
