@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -971,7 +971,7 @@ void TreeCtrl::PreferencesChanged()
   ;
 }
 
-void EditTreeLabel(wxTreeCtrl* tree, const wxTreeItemId& id)
+void TreeCtrl::EditTreeLabel(wxTreeCtrl* tree, const wxTreeItemId& id)
 {
   if (!id) return;
   wxTextCtrl* edit = tree->EditLabel(id);
@@ -990,7 +990,7 @@ void TreeCtrl::OnAddGroup(wxCommandEvent& WXUNUSED(evt))
   wxTreeItemId parentId = GetSelection();
   wxString newItemPath = (!parentId || !parentId.IsOk() || parentId == GetRootItem() || !ItemIsGroup(parentId))? wxString(_("New Group")): GetItemGroup(parentId) + GROUP_SEL_STR + _("New Group");
   if(Find(newItemPath, GetRootItem())) {
-    wxMessageBox(_("\"") + _("New Group") + _("\" ") + _("name exists"), _("Double group name"), wxOK|wxICON_ERROR);
+    wxMessageBox(_("\"") + _("New Group") + _("\" ") + _("name exists"), _("Duplicate group name"), wxOK|wxICON_ERROR);
     return;
   }
   wxTreeItemId newItem = AddGroup(tostringx(newItemPath));
@@ -1051,8 +1051,15 @@ void TreeCtrl::OnEndLabelEdit( wxTreeEvent& evt )
             const wxString itemText = GetItemText(ti);
             if ((itemText == label.c_str()) && (ti != item)) {
               evt.Veto();
-              wxMessageBox(_("Same group name exists"), _("Double group name"), wxOK|wxICON_ERROR);
-              EditTreeLabel(this, item);
+              wxMessageBox(_("Group names on the same level must be unique."), _("Duplicate group name"), wxOK|wxICON_ERROR);
+              /*
+                Wrapped in a 'CallAfter' so the veto and current event can be finalized.
+                A call to 'EditTreeLabel' will trigger a new event for editing the label
+                and will open a new text entry field, whereas the previously open seems
+                still to exists. Hence, without a delay the new event seems to be in
+                conflict with the current one.
+              */
+              CallAfter(&TreeCtrl::EditTreeLabel, this, item);
               return;
             }
             ti = GetNextSibling(ti);
@@ -1424,6 +1431,11 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
   if (m_drag_item != nullptr) { // Drag and drop started
 
     wxTreeItemId itemDst = evt.GetItem();
+    auto parentOfDragItem = GetItemParent(m_drag_item);
+    auto sxSrcGroupName = tostringx(GetItemText(parentOfDragItem));
+    StringX sxDstGroupName;
+    bool dragItemLeavesEmptyGroup = (ItemIsGroup(parentOfDragItem) && GetChildrenCount(parentOfDragItem) == 1);
+    bool isDestinationEmptyGroup = false;
     
     if(! currentItem.IsOk() && (flags & (wxTREE_HITTEST_BELOW|wxTREE_HITTEST_NOWHERE))) {
       itemDst = GetRootItem();
@@ -1442,6 +1454,10 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
         if(! ItemIsGroup(itemDst)) {              // On no group, use parent as destination
           itemDst = GetItemParent(itemDst);
         }
+        else {                                    // On group, the group needs to be removed, if it is an empty group
+          sxDstGroupName = tostringx(GetItemText(itemDst));
+          isDestinationEmptyGroup = m_core.IsEmptyGroup(sxDstGroupName);
+        }
         if(IsDescendant(itemDst, m_drag_item)) {  // Do not drag and drop into the moved tree
           wxMessageBox(_("Destination cannot be inside source tree"), _("Drag and Drop failed"), wxOK|wxICON_ERROR);
           evt.Skip();
@@ -1450,6 +1466,23 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
         }
       }
 
+      auto *commands = MultiCommands::Create(&m_core);
+
+      // If the drag'd item leaves an empty group in the tree
+      // the group needs to be created as such in the database.
+      if (dragItemLeavesEmptyGroup) {
+        commands->Add(
+          DBEmptyGroupsCommand::Create(&m_core, sxSrcGroupName, DBEmptyGroupsCommand::EG_ADD)
+        );
+      }
+      // If the destination was an empty group in the tree it is not empty now
+      // and the empty group can be removed from the database.
+      if (isDestinationEmptyGroup) {
+        commands->Add(
+          DBEmptyGroupsCommand::Create(&m_core, sxDstGroupName, DBEmptyGroupsCommand::EG_DELETE)
+        );
+      }
+
       if(! ItemIsGroup(m_drag_item)) {
         // It's only one item to handle
         CItemData *dataSrc = TreeCtrl::GetItem(m_drag_item);
@@ -1459,11 +1492,11 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
 
         if(makeCopy) {
           if (dataSrc->IsDependent()) {
-            m_core.Execute(
+            commands->Add(
               AddEntryCommand::Create(&m_core, modifiedItem, dataSrc->GetBaseUUID())
             );
           } else { // not alias or shortcut
-            m_core.Execute(
+            commands->Add(
               AddEntryCommand::Create(&m_core, modifiedItem)
             );
           }
@@ -1474,7 +1507,7 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
           modifiedItem.SetRMTime(t);
           
           // Move is same as rename
-          m_core.Execute(
+          commands->Add(
             EditEntryCommand::Create(&m_core, *dataSrc, modifiedItem)
           );
         }
@@ -1496,7 +1529,7 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
           wxTreeItemId si;
           if(ExistsInTree(itemDst, tostringx(label), si)) {
             evt.Veto();
-            wxMessageBox(_("Duplicate group name (use Shift to overrule)"), _("Double group name"), wxOK|wxICON_ERROR);
+            wxMessageBox(_("Duplicate group name (use Shift to overrule)"), _("Duplicate group name"), wxOK|wxICON_ERROR);
             m_drag_item = nullptr;
             return;
           }
@@ -1504,11 +1537,15 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
 
         if(makeCopy) {
           // On control key pressed do copy the tree
-          CreateCommandCopyGroup(m_drag_item, sxNewPath, sxOldPath, ! doOverride);
+          commands->Add(
+            CreateCommandCopyGroup(m_drag_item, sxNewPath, sxOldPath, ! doOverride)
+          );
         }
         else {
           // Without key board pressed to move, same as rename
-          CreateCommandRenamingGroup(sxNewPath, sxOldPath);
+          commands->Add(
+            CreateCommandRenamingGroup(sxNewPath, sxOldPath)
+          );
         }
         
         wxTreeItemId newItem = Find(towxstring(sxNewPath), GetRootItem());
@@ -1516,6 +1553,22 @@ void TreeCtrl::OnEndDrag(wxTreeEvent& evt)
           wxTreeCtrl::SelectItem(newItem);
       }
       setNodeAsNotEmpty(itemDst);
+
+      // If there are commands execute them
+      // otherwise delete the MultiCommand.
+      if (commands->GetSize() > 0) {
+        commands->Add(
+          UpdateGUICommand::Create(
+            &m_core,
+            UpdateGUICommand::ExecuteFn::WN_ALL,
+            UpdateGUICommand::GUI_Action::GUI_REFRESH_TREE
+          )
+        );
+        m_core.Execute(commands);
+      }
+      else {
+        delete commands;
+      }
     }
     else {
       if(m_drag_item.IsOk())
@@ -1608,12 +1661,23 @@ void TreeCtrl::FinishAddingGroup(wxTreeEvent& evt, wxTreeItemId groupItem)
     }
     StringX sxGroup = tostringx(groupName);
 
+    auto *commands = MultiCommands::Create(&m_core);
     // The new item we just added above will get removed once the update GUI callback from core happens.
-    DBEmptyGroupsCommand* cmd = DBEmptyGroupsCommand::Create(&m_core,
-                                                             sxGroup,
-                                                             DBEmptyGroupsCommand::EG_ADD);
-    if (cmd)
-      m_core.Execute(cmd);
+    commands->Add(
+      DBEmptyGroupsCommand::Create(&m_core, sxGroup, DBEmptyGroupsCommand::EG_ADD)
+    );
+
+    auto parent = GetItemParent(groupItem);
+    auto sxParentGroupName = tostringx(GetItemGroup(parent));
+    if (parent != GetRootItem() && m_core.IsEmptyGroup(sxParentGroupName)) {
+      commands->Add(
+        DBEmptyGroupsCommand::Create(&m_core, sxParentGroupName, DBEmptyGroupsCommand::EG_DELETE)
+      );
+    }
+
+    if (commands) {
+      m_core.Execute(commands);
+    }
 
     // evt.GetItem() is not valid anymore.  A new item has been inserted instead.
     // We can select it using the full path we computed earlier
@@ -1638,7 +1702,9 @@ void TreeCtrl::FinishRenamingGroup(wxTreeEvent& evt, wxTreeItemId groupItem, con
   StringX sxOldPath = tostringx(oldPath);
   StringX sxNewPath = tostringx(GetItemGroup(groupItem));
   
-  CreateCommandRenamingGroup(sxNewPath, sxOldPath);
+  ExecuteMultiCommands(
+    CreateCommandRenamingGroup(sxNewPath, sxOldPath)
+  );
 
   // The old treeItem is gone, since it was renamed.  We need to find the new one to select it
   wxTreeItemId newItem = Find(towxstring(sxNewPath), GetRootItem());
@@ -1646,7 +1712,7 @@ void TreeCtrl::FinishRenamingGroup(wxTreeEvent& evt, wxTreeItemId groupItem, con
     wxTreeCtrl::SelectItem(newItem);
 }
 
-void TreeCtrl::CreateCommandRenamingGroup(StringX sxNewPath, StringX sxOldPath)
+MultiCommands* TreeCtrl::CreateCommandRenamingGroup(StringX sxNewPath, StringX sxOldPath)
 {
   // We DON'T need to handle these two as they can only occur while moving items
   //    not removing groups as they become empty
@@ -1654,7 +1720,7 @@ void TreeCtrl::CreateCommandRenamingGroup(StringX sxNewPath, StringX sxOldPath)
 
   MultiCommands* pmcmd = MultiCommands::Create(&m_core);
   if (!pmcmd)
-    return;
+    return pmcmd;
 
   // This takes care of modifying all the actual items
   pmcmd->Add(RenameGroupCommand::Create(&m_core, sxOldPath, sxNewPath));
@@ -1672,8 +1738,7 @@ void TreeCtrl::CreateCommandRenamingGroup(StringX sxNewPath, StringX sxOldPath)
     }
   }
 
-  if (pmcmd->GetSize())
-    m_core.Execute(pmcmd);
+  return pmcmd;
 }
 
 CItemData TreeCtrl::CreateNewItemAsCopy(const CItemData *dataSrc, StringX sxNewPath, bool checkName, bool newEntry)
@@ -1764,11 +1829,11 @@ void TreeCtrl::ExtendCommandCopyGroup(MultiCommands* pmCmd, wxTreeItemId itemSrc
   }
 }
 
-void TreeCtrl::CreateCommandCopyGroup(wxTreeItemId itemSrc, StringX sxNewPath, StringX sxOldPath, bool checkName)
+MultiCommands* TreeCtrl::CreateCommandCopyGroup(wxTreeItemId itemSrc, StringX sxNewPath, StringX sxOldPath, bool checkName)
 {
   MultiCommands* pmcmd = MultiCommands::Create(&m_core);
   if (!pmcmd)
-    return;
+    return pmcmd;
   
   // Copy the selected tree with all entries
   wxASSERT(itemSrc != GetRootItem() && ItemIsGroup(itemSrc));
@@ -1791,8 +1856,14 @@ void TreeCtrl::CreateCommandCopyGroup(wxTreeItemId itemSrc, StringX sxNewPath, S
     }
   }
   
-  if (pmcmd->GetSize())
-    m_core.Execute(pmcmd);
+  return pmcmd;
+}
+
+void TreeCtrl::ExecuteMultiCommands(MultiCommands* commands)
+{
+  if (commands && commands->GetSize() > 0) {
+    m_core.Execute(commands);
+  }
 }
 
 /*!
@@ -2537,7 +2608,7 @@ void TreeCtrl::AddDnDEntries(MultiCommands *pmCmd, DnDObList &dnd_oblist, String
         pl.base_uuid = CUUID::NullUUID();
       }
     } else {
-        m_core.ParseBaseEntryPWD(cs_tmp, pl);
+        m_core.ParseAliasPassword(cs_tmp, pl);
     }
     
     if (pl.ibasedata > 0) {
