@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2025 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -25,16 +25,24 @@
 #include <iomanip>
 #include <sstream>
 
-void YubiMixin::SetupMixin(wxWindow *btn, wxWindow *status)
+int YubiMixin::s_pollingInterval = YubiMixin::POLLING_INTERVAL_DEFAULT;
+
+void YubiMixin::SetupMixin(wxEvtHandler *eventHandler, wxWindow *btn, wxWindow *status, int timerId)
 {
-  m_prompt1 = _("Click the button labeled 'Yubikey' in green"); // change via SetPrompt1
-  m_prompt2 = _("Now touch your YubiKey's button"); // change via SetPrompt2
+  m_prompt1 = _("Activate YubiKey"); // change via SetPrompt1
+  m_prompt2 = _("Touch YubiKey's button"); // change via SetPrompt2
   m_btn = btn;
   m_status = status;
   m_present = !IsYubiInserted(); // lie to trigger correct actions in timer even
-  // Hide Yubi controls if user doesn't have one:
-  if (m_btn != nullptr) m_btn->Show(yubiExists());
-  if (m_status != nullptr) m_status->Show(yubiExists());
+  if ((m_btn != nullptr) && (m_status != nullptr)) {
+    // Hide Yubi controls if user doesn't have one:
+    m_btn->Show(yubiExists());
+    m_status->Show(yubiExists());
+    if (IsPollingEnabled() && (timerId != YubiMixin::POLLING_TIMER_NONE)) {
+      m_pollingTimer = new wxTimer(eventHandler, timerId);
+      m_pollingTimer->Start(GetPollingInterval());
+    }
+  }
 }
 
 bool YubiMixin::yubiExists() const
@@ -53,7 +61,7 @@ void YubiMixin::yubiRemoved(void)
 {
   m_btn->Enable(false);
   m_status->SetForegroundColour(wxNullColour);
-  m_status->SetLabel(_("Please insert your YubiKey"));
+  m_status->SetLabel(_("Insert YubiKey"));
 }
 
 bool YubiMixin::IsYubiInserted() const
@@ -65,11 +73,10 @@ bool YubiMixin::IsYubiInserted() const
 void YubiMixin::HandlePollingTimer()
 {
   // Show Yubi controls when inserted first time:
-  if (yubiExists()) {
-    wxWindow *parent = nullptr; // assume both have same parent
-    if (m_btn != nullptr) {m_btn->Show(true); parent = m_btn->GetParent();}
-    if (m_status != nullptr) {m_status->Show(true); parent = m_btn->GetParent();}
-    if (parent != nullptr) parent->Layout();
+  if (yubiExists() && (!m_btn->IsShown() || !m_status->IsShown())) {
+    m_btn->Show(true);
+    m_status->Show(true);
+    updateLayout();
   }
 
   // Currently hmac check is blocking (ugh), so no need to check here
@@ -81,12 +88,41 @@ void YubiMixin::HandlePollingTimer()
   }
 }
 
+void YubiMixin::SetPollingInterval(int value) {
+  if (value <= YubiMixin::POLLING_INTERVAL_OFF) {
+    s_pollingInterval = YubiMixin::POLLING_INTERVAL_OFF; // indicates to disable the polling
+  }
+  else if (value < YubiMixin::POLLING_INTERVAL_MIN /* ms */) {
+    s_pollingInterval = YubiMixin::POLLING_INTERVAL_MIN; // limit the polling interval to a minimum
+  }
+  else if (value > YubiMixin::POLLING_INTERVAL_MAX /* ms */) {
+    s_pollingInterval = YubiMixin::POLLING_INTERVAL_MAX; // limit the polling interval to a maximum
+  }
+  else {
+    s_pollingInterval = value;  // the user defined polling interval
+  }
+}
+
 void YubiMixin::UpdateStatus()
 {
   if (m_present)
     yubiInserted();
   else
     yubiRemoved();
+
+  updateLayout();
+}
+
+void YubiMixin::updateLayout()
+{
+  // Update the dialog's layout as additional controls
+  // have appeared or the prompt has changed.
+  if (m_btn) {
+    auto *parent = m_btn->GetParent();
+    if (parent != nullptr) {
+      parent->GetSizer()->Layout();
+    }
+  }
 }
 
 bool YubiMixin::PerformChallengeResponse(wxWindow *win,
